@@ -22,6 +22,7 @@
 #include <glib-object.h>
 #include <gio/gio.h>
 #include <exiv2/image.hpp>
+#include <exiv2/xmpsidecar.hpp>
 #include <exiv2/exif.hpp>
 #include <exiv2/iptc.hpp>
 #include <exiv2/xmp.hpp>
@@ -311,6 +312,18 @@ static gboolean gexiv2_metadata_save_internal (GExiv2Metadata *self, Exiv2::Imag
     return TRUE;
 }
 
+gboolean gexiv2_metadata_save_external (GExiv2Metadata *self, const gchar *path, GError **error) {
+    g_return_val_if_fail (GEXIV2_IS_METADATA (self), FALSE);
+
+    try {
+        return gexiv2_metadata_save_internal (self, Exiv2::ImageFactory::create(Exiv2::ImageType::xmp, path), error);
+    } catch (Exiv2::Error &e) {
+        g_set_error_literal (error, g_quark_from_string ("GExiv2"), e.code (), e.what ());
+    }
+
+    return FALSE;
+}
+
 gboolean gexiv2_metadata_save_file (GExiv2Metadata *self, const gchar *path, GError **error) {
     g_return_val_if_fail (GEXIV2_IS_METADATA (self), FALSE);
     
@@ -616,12 +629,13 @@ gchar* gexiv2_metadata_get_comment (GExiv2Metadata *self) {
 void gexiv2_metadata_set_comment (GExiv2Metadata *self, const gchar* comment) {
     g_return_if_fail(GEXIV2_IS_METADATA (self));
     g_return_if_fail(self->priv->image.get() != NULL);
+    g_return_if_fail(comment != NULL);
     
     Exiv2::ExifData& exif_data = self->priv->image->exifData();
     Exiv2::IptcData& iptc_data = self->priv->image->iptcData();
     Exiv2::XmpData& xmp_data = self->priv->image->xmpData();
     
-    gexiv2_metadata_set_comment_internal (self, (comment != NULL) ? comment : "");
+    gexiv2_metadata_set_comment_internal (self, comment);
     exif_data ["Exif.Image.ImageDescription"] = comment;
     exif_data ["Exif.Photo.UserComment"] = comment;
     exif_data ["Exif.Image.XPComment"] = comment;
